<?php
/**
 * Namespace Teknisa\Logic\IntNutrientes\Controllers
 *
 * PHP version 5
 *
 * @category Php
 * @package  Tecfood\Integracao\Controllers
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Teknisa\Logic\IntNutrientes\Controllers;

use Geral\Entities\Nutriente;
use Geral\Entities\Organizacao;
use Teknisa\Logic\IntNutrientes\Services\EnviaNutrientes as EnviaNutrientesService;
use Teknisa\Logic\SIT\Request;
use Teknisa\Logic\SIT\Response;


/**
 * Class EnviaNutrientes para o Cliente
 *
 * PHP version 5
 *
 * @category Php
 * @package  Teknisa\Logic\IntNutrientes\Controllers
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class EnviaNutrientes
{

    /**
     * Controla o Envio de Nutrientes
     * Esta classe se refere à visão Teknisa: essa ação será executada quando o
     * cliente RECEBER os nutrientes (Rota: recNutriente).
     *
     * @param Request  $request  Request
     * @param Response $response Response
     */
    public function enviaNutrientes (Request $request, Response $response)
    {
        $json = $request->getData();

        if (empty($json) === false) {

            if (!is_array($json)) {
                $json = json_decode($json, true);
            }

            $nutr = self::validaOrganizacao($json['NRORGINT']);
            if ($nutr) {
                $nutr = EnviaNutrientesService::enviaNutrientes($json['NRORG']);
            } else {
                $nutr = tk_get_message_by_name('msg_ger07600_msgErroOrganizacao');
            }

        } else {
            //$nutr = array('msg_ger07600_parametroIncorreto', array());
            $nutr = tk_get_message_by_name('msg_ger07600_parametroIncorreto');
        }

        $response->setData($nutr);
    }

    /**
     * Verifica se a Organizacao passada por parametro é válida.
     * Retorna true se a Organização existe e está ativa.
     *
     * @param String $nrorgint Organizaçao
     *
     * @return bool.
     */
    public static function validaOrganizacao ($nrorgint)
    {
        $reg = Organizacao::getObjectByWhere(
            "NRORG = ?",
            array($nrorgint)
        );

        $retorno = false;
        if ($reg instanceof Organizacao) {
            if ($reg->getIdativo() == 'S') {
                $retorno = true;
            }
        }

        return $retorno;
    }
}
