import {
  Metadata, Loader, Http, IEventParam,
} from '@zeedhi/core';
import {
  Tabs, TreeGridEditable, Form, Button, DialogService,
} from '@zeedhi/common';

export class Pla01300ImportarFatorConversao {
  public gridEditController = Loader.getInstance('GridEditableController');
    
  private utilities = Loader.getInstance('Utilities');
    
  public appController = Loader.getInstance('AppController');
  
  public prato = Loader.getInstance('Pla01300PratoController');
  
  public confirmaFatorCorrecao(component: any) {
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    if (tabPratos.activeTab === 2) {
      if (this.prato.operatorValid !== false) {
        this.dialogConfirmaFatorCorrecao();
      } else {
        this.utilities.showAlert('Alert', 'pme::modificacaoRecPadrao', 'warning');
        this.prato.openModalGroupOperador(component);
      }
    } else this.dialogConfirmaFatorCorrecao();
  }
    
  public dialogConfirmaFatorCorrecao() {
    DialogService.show({
      name: 'finalizar',
      type: 'warning',
      title: 'pme::atencao',
      text: 'pme::alertImportarFatorCorrecao',
      buttons: [
        {
          name: 'salvarAjusteQuantidades',
          component: 'ZdButton',
          label: 'pme::sim',
          events: { click: () => this.importarFatorCorrecao() },
          outline: true,
        },
        {
          name: 'no',
          component: 'ZdButton',
          label: 'pme::nao',
          events: { click: () => DialogService.hide() },
        },
        {
          name: 'progressLine',
          component: 'ZdProgress',
          label: 'Progress',
          indeterminate: true,
          cssClass: 'loading-progress-line',
        },
      ],
    });
  }
  
  public verificaCampos({ component }: IEventParam<Button>) {
    this.updateGrid();
    
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    let tipocard;
    let cdfilial;
    let cdserv;
    let grid: any;

    if (tabPratos.activeTab === 2) {
      grid = Metadata.getInstance('RECIPE_STANDARD');
      if (grid.selectedRows.length === 0) {
        this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'warning');
      } else {
        this.confirmaFatorCorrecao(component);
      }
    } else if (tabPratos.activeTab === 3) {
      const formFiltroTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
      tipocard = formFiltroTpCard.value.TIPOCARD?.CDTIPOCARD;
      if (tipocard === undefined) {
        this.utilities.showAlert('alert', 'pme::tipoCardapioDeveSerInformado', 'warning');
        DialogService.hide();
      } else {
        grid = Metadata.getInstance('RECIPE_TIPOCARD');
        if (grid.selectedRows.length === 0) {
          this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'warning');
        } else {
          this.confirmaFatorCorrecao(component);
        }
      }
    } else if (tabPratos.activeTab === 4) {
      const formFiltroUnidade = Metadata.getInstance<Form>('FORM_LOCAL');
      cdfilial = formFiltroUnidade.value.BRANCH_LOCAL?.CDFILIAL;
      if (cdfilial === undefined) {
        this.utilities.showAlert('alert', 'pme::unidDeveSerInformado', 'warning');
        DialogService.hide();
      } else {
        grid = Metadata.getInstance('RECIPE_LOCAL');
        if (grid.selectedRows.length === 0) {
          this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'warning');
        } else {
          this.confirmaFatorCorrecao(component);
        }
      }
    } else if (tabPratos.activeTab === 5) {
      const formFiltroServico = Metadata.getInstance<Form>('FORM_SERVICE');
      cdfilial = formFiltroServico.value.BRANCH_SERVICE?.CDFILIAL;
      cdserv = formFiltroServico.value.SERVICE?.CDSERVFILI;
      if (cdserv === undefined) {
        this.utilities.showAlert('alert', 'pme::unidEservDevemSerInformados', 'warning');
        DialogService.hide();
      } else {
        grid = Metadata.getInstance('RECIPE_SERVICE');
        if (grid.selectedRows.length === 0) {
          this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'warning');
        } else {
          this.confirmaFatorCorrecao(component);
        }
      }
    } else if (tabPratos.activeTab === 7) {
      grid = Metadata.getInstance('RECIPE_REGION');
      if (grid.selectedRows.length === 0) this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'error');
      else this.confirmaFatorCorrecao(component);
    } else if (tabPratos.activeTab === 6) {
      grid = Metadata.getInstance('RECIPE_PADRAOQUALIDADE');
      if (grid.selectedRows.length === 0) this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'error');
      else this.confirmaFatorCorrecao(component);
    }
  }
  
  public updateGrid() {
    let grid: any;
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    
    if (tabPratos.activeTab === 2) grid = Metadata.getInstance('RECIPE_STANDARD');
    else if (tabPratos.activeTab === 3) grid = Metadata.getInstance('RECIPE_TIPOCARD');
    else if (tabPratos.activeTab === 4) grid = Metadata.getInstance('RECIPE_LOCAL');
    else if (tabPratos.activeTab === 5) grid = Metadata.getInstance('RECIPE_SERVICE');
    else if (tabPratos.activeTab === 6) grid = Metadata.getInstance('RECIPE_PADRAOQUALIDADE');
    else if (tabPratos.activeTab === 7) grid = Metadata.getInstance('RECIPE_REGION');
    
    this.gridEditController.reload({ component: grid });
  }
  
  public importarFatorCorrecao() {
    const salvar = Metadata.getInstance<Button>('salvarAjusteQuantidades');
    this.utilities.activeLoadingButton(salvar);
    
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    const prato = currentRow.CDPRATO;
    const filAux = currentRow.CDFILAUXPRAT || 'P';
    const central = this.appController.getCdCentral();
    
    let tipoReceita;
    let tipocard;
    let cdfilial;
    let cdserv;
    let grid: any;
    let form: any;
    let row: any;
    let padraoQuali;
    let regiao;
    
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');

    if (tabPratos.activeTab === 2) {
      // qtAtiva = 'QTPRODPRAT';
      tipoReceita = 'P';
      grid = Metadata.getInstance('RECIPE_STANDARD');
      row = grid.selectedRows;
    } else if (tabPratos.activeTab === 3) {
      grid = Metadata.getInstance('RECIPE_TIPOCARD');
      row = grid.selectedRows;
      tipoReceita = 'C';
      form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      tipocard = form.value.TIPOCARD?.CDTIPOCARD;
      if (tipocard === undefined) {
        this.utilities.showAlert('alert', 'pme::tipoCardapioDeveSerInformado', 'error');
      }
      // qtAtiva = 'QTPRODPRATTP';
    } else if (tabPratos.activeTab === 4) {
      grid = Metadata.getInstance('RECIPE_LOCAL');
      row = grid.selectedRows;
      form = Metadata.getInstance<Form>('FORM_LOCAL');
      cdfilial = form.value.BRANCH_LOCAL?.CDFILIAL;
      tipoReceita = 'L';
      if (cdfilial === undefined) {
        this.utilities.showAlert('alert', 'pme::unidDeveSerInformado', 'error');
      }
      // qtAtiva = 'QTPRODRECLOC';
    } else if (tabPratos.activeTab === 5) {
      tipoReceita = 'S';
      grid = Metadata.getInstance('RECIPE_SERVICE');
      row = grid.selectedRows;
      form = Metadata.getInstance<Form>('FORM_SERVICE');
      cdfilial = form.value.BRANCH_SERVICE?.CDFILIAL;
      cdserv = form.value.SERVICE?.CDSERVFILI;
      if (cdserv === undefined) {
        this.utilities.showAlert('alert', 'pme::unidEservDevemSerInformados', 'error');
      }
      // qtAtiva = 'QTPRODRECSER';
    } else if (tabPratos.activeTab === 7) {
      const formRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
      if (formRegiao.validate()) {
        grid = Metadata.getInstance('RECIPE_REGION');
        row = grid.selectedRows;
        tipoReceita = 'R';
        padraoQuali = formRegiao.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
        regiao = formRegiao.value.NMREGIAO.CDREGIAO;
      } else this.utilities.showAlert('alert', 'pme::regiaoDeveSerInformado', 'error');
      // qtAtiva = 'QTPRODRECPADQ';
    } else if (tabPratos.activeTab === 6) {
      const formPadQuali = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      if (formPadQuali.validate()) {
        grid = Metadata.getInstance('RECIPE_PADRAOQUALIDADE');
        row = grid.selectedRows;
        tipoReceita = 'Q';
        padraoQuali = formPadQuali.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
      } else this.utilities.showAlert('alert', 'pme::padraoQualidadeDeveSerInformado', 'error');
      // qtAtiva = 'QTPRODRECREGIAO';
    }
    
    const valoresFixos = {
      CDPRATO: prato,
      CDFILAUXPRAT: filAux,
      TIPORECEITA: tipoReceita,
      CDSERVFILI: cdserv,
      CDTIPOCARD: tipocard,
      CDFILIAL: cdfilial,
      CDFILCENTPME: central,
      NRPADRAOQUALIDADE: padraoQuali,
      CDREGIAO: regiao,
    };
      
    Http.post('/importarFatorCorrecao', { row, valoresFixos }).then(() => {
      this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
    }).catch((error) => {
      this.utilities.showAlert('alertError', error, 'error');
    }).finally(() => {
      this.utilities.disableLoadingButton(salvar);
      DialogService.hide();
      this.gridEditController.reload({ component: grid });
    });
  }
}
